@@ -19,9 +19,9 @@ class Export(object_tools.ObjectTool):
     def serialize(self, format, queryset, fields):
         serializer = serializers.get_serializer(format)()
         if fields:
-            return serializer.serialize(queryset, fields=fields)
+            return serializer.serialize(queryset, fields=fields, indent=4)
         else:
-            return serializer.serialize(queryset)
+            return serializer.serialize(queryset, indent=4)
 
     def gen_filename(self, format):
         app_label = self.model._meta.app_label
@@ -53,7 +53,8 @@ class Export(object_tools.ObjectTool):
 
         data = self.serialize(format, queryset, fields)
         filename = self.gen_filename(format)
-        response = HttpResponse(data, mimetype=mimetypes.guess_type(filename)[0])
+        response = HttpResponse(data, mimetype=mimetypes.guess_type(\
+                filename)[0])
         response['Content-Disposition'] = 'attachment; filename=%s' % filename
         return response
 
@@ -68,6 +69,7 @@ class Export(object_tools.ObjectTool):
         context = {'adminform': adminform}
         context.update(extra_context or {})
         context_instance = template.RequestContext(request)
-        return render_to_response('export/export_form.html', context, context_instance=context_instance)
+        return render_to_response('export/export_form.html', context, \
+                context_instance=context_instance)
 
 object_tools.tools.register(Export)
